@@ -10,7 +10,7 @@
 
 from __future__ import absolute_import, print_function
 
-FORMATTER_BADGES_ALLOWED_TITLES = ['DOI']
+FORMATTER_BADGES_ALLOWED_TITLES = ["DOI"]
 """List of allowed titles in badges."""
 
 FORMATTER_BADGES_TITLE_MAPPING = {}
