@@ -20,33 +20,34 @@ from invenio_formatter import InvenioFormatter
 def test_version():
     """Test version import."""
     from invenio_formatter import __version__
+
     assert __version__
 
 
 def test_init():
     """Test extension initialization."""
-    app = Flask('testapp')
+    app = Flask("testapp")
     ext = InvenioFormatter(app)
-    assert 'invenio-formatter' in app.extensions
+    assert "invenio-formatter" in app.extensions
 
-    app = Flask('testapp')
+    app = Flask("testapp")
     ext = InvenioFormatter()
-    assert 'invenio-formatter' not in app.extensions
+    assert "invenio-formatter" not in app.extensions
     ext.init_app(app)
-    assert 'invenio-formatter' in app.extensions
+    assert "invenio-formatter" in app.extensions
 
 
 def test_badge_enable_disable():
     """Test if badge is disabled if CairoSVG is not installed."""
-    app = Flask('testapp')
+    app = Flask("testapp")
     InvenioFormatter(app)
-    assert app.config['FORMATTER_BADGES_ENABLE'] is True
-    assert 'invenio_formatter_badges' in app.blueprints
+    assert app.config["FORMATTER_BADGES_ENABLE"] is True
+    assert "invenio_formatter_badges" in app.blueprints
 
-    with patch('invenio_formatter.ext.get_distribution') as f:
+    with patch("invenio_formatter.ext.get_distribution") as f:
         f.side_effect = DistributionNotFound
 
-        app = Flask('testapp')
+        app = Flask("testapp")
         InvenioFormatter(app)
-        assert app.config['FORMATTER_BADGES_ENABLE'] is False
-        assert 'invenio_formatter_badges' not in app.blueprints
+        assert app.config["FORMATTER_BADGES_ENABLE"] is False
+        assert "invenio_formatter_badges" not in app.blueprints
